@@ -3,17 +3,7 @@ package VIM::Packager;
 use warnings;
 use strict;
 
-=head1 NAME
-
-VIM::Packager
-
-=head1 VERSION
-
-Version 0.07
-
-=cut
-
-our $VERSION = '0.07';
+# ABSTRACT: Vim Packager builder / installer
 
 =head1 SYNOPSIS
 
@@ -22,11 +12,6 @@ our $VERSION = '0.07';
 =head1 DESCRIPTION
 
 
-
-=head1 FUNCTIONS
-
-=cut
-
 =head1 REPOSITORY 
 
 L<http://github.com/c9s/vim-packager>
