@@ -13,6 +13,10 @@ use File::Find;
 our $VERSION = 0.0.1;
 my  $VERBOSE = 1;
 
+use constant {
+    LIBPATH  => 'vimlib',
+};
+
 =head1 SYNOPSIS
 
     $ vim-packager build 
@@ -20,31 +24,8 @@ my  $VERBOSE = 1;
         # auto install dependency 
     $ make install
 
-=head1 Constants
-
-LIBPATH: F<vimlib/>
-
 =cut
 
-use constant {
-    LIBPATH  => 'vimlib',
-};
-
-=head1 Makefile Helper Functions
-
-=head2 multi_line Array:Lines
-
-=head2 add_macro  ArrayRef:Makefile Lines , String: Macro Name , String: Macro 
-
-=head2 new_section ArrayRef:Makefile Lines , String: Section Name , Array: Depended macro names
-
-=head2 add_st ArrayRef:Makefile Lines , String: Statement , Array: Statement Arguments
-
-Statement Arguments is for Statement string, which is in sprintf format.
-
-=head2 add_noop_st ArrayRef:Makefile Lines
-
-=cut
 
 sub multi_line {
     my @items = @_;
@@ -64,19 +45,23 @@ sub new_section {
 }
 
 sub add_st {
-    my ($ref, $st , @args ) = @_;
-    push @{ $ref } , qq|\t\t| . sprintf($st , @args);
+    my $ref = shift;
+    my $st = shift;
+    push @{ $ref } , qq|\t\t| . $st;
+}
+
+sub meta {
+    my $self = shift;
+    $self->{meta} = shift if @_;
+    return $self->{meta};
 }
 
 sub add_noop_st {
 	add_st $_[0] => q|$(NOECHO) $(NOOP)|;
 }
 
-=head1 Main Functions
 
-=head2 new
 
-=cut
 
 sub new { 
     my $class = shift;
@@ -173,28 +158,9 @@ sub new {
             { main   => $main } ] );
 }
 
-=head2 meta
-
-return current meta object.
-
-=cut
-
-sub meta {
-    my $self = shift;
-    $self->{meta} = shift if @_;
-    return $self->{meta};
-}
 
 
 
-
-
-=head2 section_all
-
-
-
-=cut
-
 sub section_all {
     my $self = shift;
     my $main = shift;
@@ -202,12 +168,6 @@ sub section_all {
 	add_noop_st $main;
 }
 
-=head2 section_install
-
-
-
-=cut
-
 sub section_install {
     my $self = shift;
     my $main = shift;
@@ -215,12 +175,6 @@ sub section_install {
 	add_noop_st $main;
 }
 
-=head2 section_pure_install
-
-
-
-=cut
-
 sub section_pure_install {
     my ($self,$main,$makefile) = @_;
 
@@ -249,12 +203,6 @@ sub section_pure_install {
     }
 }
 
-=head2 section_deps
-
-
-
-=cut
-
 sub section_deps {
     my $self = shift;
     my $main = shift;
@@ -289,10 +237,6 @@ sub section_deps {
     }
 }
 
-=head2 section_link
-
-
-=cut
 
 sub section_link {
     my ($self,$main , $filelist) = @_;
